# tgl2rdm

[Toggl Track](https://toggl.com/) -> [Redmine](https://www.redmine.org/) synchonization.

## Installation
```sh
pip install tgl2rdm
```

## Configuration
You can just copy [`config.example.toml`](./config.example.toml) and [`logger.example.toml`](./logger.example.toml) to `~/.config/tgl2rdm/` as `config.toml` and `logger.toml` representivly.
